@@ -1,17 +1,17 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::CheckSelfDependency; # git description: v0.009-1-ged0b9db
+package Dist::Zilla::Plugin::CheckSelfDependency; # git description: v0.010-10-g077e534
 # ABSTRACT: Check if your distribution declares a dependency on itself
 # KEYWORDS: plugin validate distribution prerequisites dependencies modules
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::CheckSelfDependency::VERSION = '0.010';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '0.011';
 use Moose;
 with 'Dist::Zilla::Role::AfterBuild',
     'Dist::Zilla::Role::FileFinderUser' => {
         default_finders => [ ':InstallModules' ],
     },
+    'Dist::Zilla::Role::ModuleMetadata',
 ;
-use Module::Metadata 1.000023;
 use CPAN::Meta::Prereqs 2.132830;   # for merged_requirements
 use CPAN::Meta::Requirements;
 use namespace::autoclean;
@@ -49,16 +49,10 @@ sub after_build
     # but for now, we will check our modules explicitly for provided packages.
     foreach my $file (@{$self->found_files})
     {
-        $self->log_fatal(sprintf('Could not decode %s: %s', $file->name, $file->added_by))
+        $self->log_fatal([ 'Could not decode %s: %s', $file->name, $file->added_by ])
             if $file->can('encoding') and $file->encoding eq 'bytes';
 
-        my $fh;
-        ($file->can('encoding')
-            ? open $fh, sprintf('<:encoding(%s)', $file->encoding), \$file->encoded_content
-            : open $fh, '<', \$file->content)
-                or $self->log_fatal('cannot open handle to ' . $file->name . ' content: ' . $!);
-
-        my @packages = Module::Metadata->new_from_handle($fh, $file->name)->packages_inside;
+        my @packages = $self->module_metadata_for_file($file)->packages_inside;
         foreach my $package (@packages)
         {
             if (exists $prereqs{$package}
@@ -102,7 +96,7 @@ Dist::Zilla::Plugin::CheckSelfDependency - Check if your distribution declares a
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
